@@ -14,6 +14,7 @@ from falocalrepo_database import Database as _Database
 from falocalrepo_database import Table
 from falocalrepo_database.selector import Selector
 from falocalrepo_database.selector import SelectorBuilder as Sb
+from falocalrepo_database.tables import JournalsColumns
 from falocalrepo_database.tables import SubmissionsColumns
 from falocalrepo_database.tables import UsersColumns
 from falocalrepo_database.tables import journals_table
@@ -27,7 +28,7 @@ default_order: dict[str, str] = {submissions_table: "desc", journals_table: "des
 
 @cache
 def clean_username(username: str, exclude: str = "") -> str:
-    return sub(rf"[^a-zA-Z0-9\-.~{exclude}]", "", username.lower().strip())
+    return sub(rf"[^a-zA-Z\d\-.~{exclude}]", "", username.lower().strip())
 
 
 def format_value(value: str, *, like: bool = False) -> str:
@@ -81,12 +82,6 @@ class Database(_Database):
         elif err := compare_version(self.version, patch=False):
             raise err
 
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        self.close()
-
     @property
     def m_time(self):
         return self.path.stat().st_mtime
@@ -123,7 +118,7 @@ class Database(_Database):
 
     @cache
     def _load_submission_files_cached(self, submission_id: int, *, _cache=None
-                                      ) -> tuple[Path | None, Path | None]:
+                                      ) -> tuple[list[Path] | None, Path | None]:
         return self.submissions.get_submission_files(submission_id)
 
     @cache
@@ -176,10 +171,15 @@ class Database(_Database):
         order = order or default_order[table]
         db_table: Table
 
-        if (table := table.upper()) in (submissions_table.upper(), journals_table.upper()):
+        if (table := table.upper()) == submissions_table.upper():
             cols_results = [SubmissionsColumns.ID.value, SubmissionsColumns.AUTHOR.value,
-                            SubmissionsColumns.DATE.value, SubmissionsColumns.TITLE.value]
-            db_table = self.submissions if table == submissions_table else self.journals
+                            SubmissionsColumns.DATE.value, SubmissionsColumns.TITLE.value,
+                            SubmissionsColumns.FILEEXT.value]
+            db_table = self.submissions
+        elif table == journals_table.upper():
+            cols_results = [JournalsColumns.ID.value, JournalsColumns.AUTHOR.value,
+                            JournalsColumns.DATE.value, JournalsColumns.TITLE.value]
+            db_table = self.journals
         else:
             default_field = "username"
             cols_results = [UsersColumns.USERNAME.value, UsersColumns.FOLDERS.value, UsersColumns.ACTIVE.value]
@@ -189,18 +189,21 @@ class Database(_Database):
         cols_list: list[str] = [c.name for c in db_table.columns if c.type in (list, set)]
         col_id: Column = db_table.key
 
-        sql, values = query_to_sql(query,
-                                   default_field,
-                                   [*map(str.lower,
-                                         {*cols_table, "any", "keywords", "message", "filename"} -
-                                         {"ID", "AUTHOR", "FILESAVED", "USERUPDATE", "ACTIVE"})],
-                                   {"author": "replace(author, '_', '')",
-                                    "lower": "replace(author, '_', '')",
-                                    "keywords": "tags",
-                                    "message": "description",
-                                    "filename": "fileurl",
-                                    "any": f"({'||'.join(cols_table)})"},
-                                   score=sort.lower() == "relevance")
+        sql, values = query_to_sql(
+            query,
+            default_field,
+            [*map(str.lower,
+                  {*cols_table, "any", "keywords", "message", "filename"} -
+                  {"ID", "FILESAVED", "USERUPDATE", "ACTIVE"})],
+            {"author": "replace(author, '_', '')",
+             "lower": "replace(author, '_', '')",
+             "keywords": "tags",
+             "message": "description",
+             "filename": "fileurl",
+             "any": "(" +
+                    '||'.join(set(cols_table) - {'FAVORITE', 'FILESAVED', 'USERUPDATE', 'ACTIVE'}) +
+                    ")"},
+            score=sort.lower() == "relevance")
 
         results: list[dict]
         if sort.lower() == "relevance":
@@ -249,7 +252,7 @@ class Database(_Database):
     def load_submission(self, submission_id: int) -> dict | None:
         return self._load_submission_cached(submission_id, _cache=self.m_time)
 
-    def load_submission_files(self, submission_id: int) -> tuple[Path | None, Path | None]:
+    def load_submission_files(self, submission_id: int) -> tuple[list[Path] | None, Path | None]:
         return self._load_submission_files_cached(submission_id, _cache=self.m_time)
 
     def load_submission_comments(self, submission_id: int) -> list[dict]:
@@ -285,7 +288,7 @@ class Database(_Database):
     def load_submission_comments_uncached(self, submission_id: int) -> list[dict]:
         return self._load_submission_comments_cached.__wrapped__(self, submission_id)
 
-    def load_submission_files_uncached(self, submission_id: int) -> tuple[Path | None, Path | None]:
+    def load_submission_files_uncached(self, submission_id: int) -> tuple[list[Path] | None, Path | None]:
         return self._load_submission_files_cached.__wrapped__(self, submission_id)
 
     def load_journal_uncached(self, journal_id: int) -> dict | None:
