@@ -16,6 +16,7 @@ from sqlite3 import OperationalError
 from typing import Any
 from typing import Callable
 from typing import Coroutine
+from webbrowser import open as open_browser
 from zipfile import ZipFile
 
 from PIL import Image
@@ -82,6 +83,8 @@ class Settings(BaseSettings):
     ssl_cert: Path = None
     ssl_key: Path = None
     precache: bool = False
+    open_browser: bool = True
+    address: str = None
     username: str = None
     password: str = None
 
@@ -219,6 +222,8 @@ def log_settings():
             logger.info(
                 f"Caching {table.name.upper()}:{(sort := search_settings.sort[table.name]).upper()}:{order.upper()}")
             settings.database.load_search(table.name, "", "id" if sort.lower() == "date" else sort, order)
+    if settings.open_browser:
+        open_browser(settings.address)
 
 
 @app.on_event("shutdown")
@@ -474,17 +479,18 @@ async def serve_submission(request: Request, id_: int):
         return error_response(request, 404, "Submission not found",
                               [("Open on Fur Affinity", f"{fa_base_url}/view/{id_}")])
 
-    f: Path | None = None
-    if sub["FILEEXT"] == "txt" and sub["FILESAVED"] & 0b10:
-        f, _ = settings.database.load_submission_files(id_)
+    fs: list[Path] | None = None
+    if "txt" in sub["FILEEXT"] and sub["FILESAVED"] & 0b10:
+        fs, _ = settings.database.load_submission_files(id_)
     p, n = settings.database.load_prev_next(submissions_table, id_)
     return HTMLResponse(minify(templates.get_template("submission.html").render({
         "app": app.title,
         "title": f"{sub['TITLE']} by {sub['AUTHOR']}",
         "submission": sub | {"DESCRIPTION": clean_html(sub["DESCRIPTION"])},
-        "file_text": bbcode_to_html(f.read_text(detect_encoding(f.read_bytes())["encoding"], "ignore")) if f else None,
-        "filename": f"submission{('.' + sub['FILEEXT']) * bool(sub['FILEEXT'])}",
-        "filename_id": f"{sub['ID']:010d}{('.' + sub['FILEEXT']) * bool(sub['FILEEXT'])}",
+        "files_text": [bbcode_to_html(fs[i].read_text(detect_encoding(fs[i].read_bytes())["encoding"], "ignore"))
+                       for i, ext in enumerate(sub['FILEEXT']) if ext.lower() == "txt"] if fs else [],
+        "filenames": [f"submission{('.' + ext) * bool(ext)}" for ext in sub['FILEEXT']],
+        "filenames_id": [f"{sub['ID']:010d}{('.' + ext) * bool(ext)}" for ext in sub['FILEEXT']],
         "comments": prepare_comments(settings.database.load_submission_comments(id_)),
         "prev": p,
         "next": n,
@@ -493,11 +499,30 @@ async def serve_submission(request: Request, id_: int):
 
 
 @app.get("/submission/{id_}/file/")
-@app.get("/submission/{id_}/file/{_filename}")
-async def serve_submission_file(id_: int, _filename=None):
-    if (f := settings.database.load_submission_files(id_)[0]) is None or not f.is_file():
+@app.get("/submission/{id_}/file/{n}")
+@app.get("/submission/{id_}/file/{n}/{_filename}")
+async def serve_submission_file(id_: int, n: int = 0, _filename=None):
+    if (fs := settings.database.load_submission_files(id_)[0]) is None or not fs[n].is_file():
         return Response(status_code=404)
-    return FileResponse(f)
+    return FileResponse(fs[n])
+
+
+@app.get("/submission/{id_}/files/")
+@app.get("/submission/{id_}/files/{_filename}")
+@app.get("/submission/{id_}/files/{n1}-{n2}")
+@app.get("/submission/{id_}/files/{n1}-{n2}/{_filename}")
+async def serve_submission_zip(id_: int, n1: int = 0, n2: int = None, _filename=None):
+    if id_ not in settings.database.submissions:
+        raise HTTPException(404)
+
+    sub_files, _ = settings.database.load_submission_files(id_)
+
+    with ZipFile(f_obj := BytesIO(), "w") as z:
+        for sub_file in sub_files[n1:(n2 + 1) if n2 is not None else None]:
+            z.writestr(sub_file.name, sub_file.read_bytes())
+
+    f_obj.seek(0)
+    return StreamingResponse(f_obj, media_type="application/zip")
 
 
 @app.get("/submission/{id_}/thumbnail/")
@@ -509,7 +534,7 @@ async def serve_submission_file(id_: int, _filename=None):
 @app.get("/submission/{id_}/thumbnail/{x}x{y}>/")
 @app.get("/submission/{id_}/thumbnail/{x}x{y}>/{_filename}")
 async def serve_submission_thumbnail(id_: int, x: int = None, y: int = None, _filename=None):
-    f, t = settings.database.load_submission_files(id_)
+    fs, t = settings.database.load_submission_files(id_)
     if t is not None and t.is_file():
         if not x and not y:
             return FileResponse(t)
@@ -518,9 +543,9 @@ async def serve_submission_thumbnail(id_: int, x: int = None, y: int = None, _fi
             img.save(f_obj := BytesIO(), img.format, quality=95)
             f_obj.seek(0)
             return StreamingResponse(f_obj, 201, media_type=f"image/{img.format}".lower())
-    elif f is not None and f.is_file():
+    elif fs and fs[0].is_file():
         try:
-            with Image.open(f) as img:
+            with Image.open(fs[0]) as img:
                 img.thumbnail((x or y or 400, y or x or 400))
                 img.save(f_obj := BytesIO(), img.format, quality=95)
                 f_obj.seek(0)
@@ -537,10 +562,11 @@ async def serve_submission_zip(id_: int, _filename=None):
     if (sub := settings.database.load_submission(id_)) is None:
         raise HTTPException(404)
 
-    sub_file, sub_thumb = settings.database.load_submission_files(id_)
+    sub_files, sub_thumb = settings.database.load_submission_files(id_)
 
     with ZipFile(f_obj := BytesIO(), "w") as z:
-        z.writestr(sub_file.name, sub_file.read_bytes()) if sub_file else None
+        for sub_file in sub_files:
+            z.writestr(sub_file.name, sub_file.read_bytes())
         z.writestr(sub_thumb.name, sub_thumb.read_bytes()) if sub_thumb else None
         z.writestr("description.html", sub["DESCRIPTION"].encode())
         z.writestr("metadata.json", dumps({k: v for k, v in serialise_entry(sub).items()
@@ -661,10 +687,12 @@ def run_redirect(host: str, port_listen: int, port_redirect: int):
 
 def server(database_path: str | PathLike, host: str = "0.0.0.0", port: int = None,
            ssl_cert: str | PathLike | None = None, ssl_key: str | PathLike | None = None,
-           redirect_port: int = None, precache: bool = False, authentication: str = None):
+           redirect_port: int = None, precache: bool = False, authentication: str = None,
+           browser: bool = True):
     if redirect_port:
         return run_redirect(host, port, redirect_port)
     settings.precache = precache
+    settings.open_browser = browser
     if authentication:
         settings.username = authentication.split(":")[0]
         settings.password = authentication.split(":", 1)[1] if ":" in authentication else ""
@@ -677,6 +705,9 @@ def server(database_path: str | PathLike, host: str = "0.0.0.0", port: int = Non
         elif not settings.ssl_key.is_file():
             raise FileNotFoundError(f"SSL private key {settings.ssl_key}")
         run_args |= {"port": port or 443, "ssl_certfile": settings.ssl_cert, "ssl_keyfile": settings.ssl_key}
+    settings.address = f"{'https' if settings.ssl_cert else 'http'}://" \
+                       f"{'localhost' if host == '0.0.0.0' else host}" \
+                       f"{f':{port}' if port else ''}"
     run_args |= {"port": run_args.get("port", port) or 80}
     with Database(Path(database_path).resolve()) as settings.database:
         search_settings.load(settings.database.load_settings("SEARCH"))
